<?php

if (!defined('ABSPATH'))
    exit;

class ADS_Core {

    /**
     * The single instance
     * @var    object
     * @access  private
     * @since    1.0.0
     */
    private static $_instance = null;

    /**
     * Settings class object
     * @var     object
     * @access  public
     * @since   1.0.0
     */
    public $settings = null;

    /**
     * The version number.
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $_version;

    /**
     * The token.
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $_token;

    /**
     * The main plugin file.
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $file;

    /**
     * The main plugin directory.
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $dir;

    /**
     * The plugin assets directory.
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $assets_dir;

    /**
     * The plugin assets URL.
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $assets_url;

    /**
     * Suffix for Javascripts.
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $templates_url;

    /**
     * Suffix for Javascripts.
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $script_suffix;

    /**
     * For menu instance
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $menu;

    /**
     * For template
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $plugin_slug;

    /**
     * Faq detected in the current post
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $donationDetected = false;

    /**
     * Shorcote detected ?
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $checkedSc = false;

    /**
     * Constructor function.
     * @access  public
     * @since   1.0.0
     * @return  void
     */
    public function __construct($file = '', $version = '1.0.0') {
        $this->_version = $version;
        $this->_token = 'adns';
        $this->plugin_slug = 'adns';

        $this->file = $file;
        $this->dir = dirname($this->file);
        $this->assets_dir = trailingslashit($this->dir) . 'assets';
        $this->assets_url = esc_url(trailingslashit(plugins_url('/assets/', $this->file)));

        $upload_dir = wp_upload_dir();
        if (!is_dir($upload_dir['basedir'] . '/AttractiveDonations')) {
            mkdir($upload_dir['basedir'] . '/AttractiveDonations');
            chmod($upload_dir['basedir'] . '/AttractiveDonations', 0747);
        }
        $this->uploadns_dir = $upload_dir['basedir'] . '/AttractiveDonations/';
        $this->uploadns_url = $upload_dir['baseurl'] . '/AttractiveDonations/';

        add_action('plugins_loaded', array($this, 'init_localization'));
        add_filter('the_content', array($this, 'preview_content'));
        add_shortcode('attractive-donation', array($this, 'adns_shortcode'));
        add_filter('the_posts', array($this, 'conditionally_add_scripts_and_styles'));
        add_action('wp_ajax_nopriv_adns_stripePreparePayment', array($this, 'stripePreparePayment'));
        add_action('wp_ajax_adns_stripePreparePayment', array($this, 'stripePreparePayment'));
    }

    /*
     * Plugin init localization
     */

    public function init_localization() {
        $moFiles = scandir(trailingslashit($this->dir) . 'languages/');
        foreach ($moFiles as $moFile) {
            if (strlen($moFile) > 3 && substr($moFile, -3) == '.mo' && strpos($moFile, get_locale()) > -1) {
                load_textdomain('adns', trailingslashit($this->dir) . 'languages/' . $moFile);
            }
        }
    }

    function preview_content($content) {
        if (isset($_GET['adns_action']) && $_GET['adns_action'] == 'preview') {
            $content = do_shortcode('[attractive-donation donation="' . $_GET['donation'] . '"]');
        }
        return $content;
    }

    public function adns_shortcode($attributes, $content = null) {
        global $wpdb;
        $response = "";
        $donation = 0;
        extract(shortcode_atts(array(
            'attractive-donation' => 0,
            'donation' => 0), $attributes));

        if ($donation == 0) {
            $table_name = $wpdb->prefix . "adns_donations";
            $donationReq = $wpdb->get_results("SELECT id FROM $table_name ORDER BY id ASC LIMIT 1");
            $donationReq = $donationReq[0];
            $donation = $donationReq->id;
        }
        if (is_numeric($donation) && $donation > 0) {
            $this->donationDetected = true;
            $table_donations = $wpdb->prefix . "adns_donations";
            $table_steps = $wpdb->prefix . "adns_steps";
            $donations = $wpdb->get_results("SELECT * FROM $table_donations WHERE id=$donation LIMIT 1");
            $steps = $wpdb->get_results("SELECT * FROM $table_steps WHERE donationID=$donation ORDER BY id ASC");
            if (count($donations) > 0) {
                $imageSrc = esc_url($this->assets_url) . 'img/gift-256.png';
                $donation = $donations[0];
                $imageDes = $donation->title;

                $verticalClass = "";
                if ($donation->barVertical) {
                    $verticalClass = 'adns_vertical';
                }

                $response = '';
                $classHidden = '';
                $classModal = '';
                if ($donation->displayMode == 'modal' || $donation->displayMode == 'modalButton') {
                    $classModal = 'adns_modal';
                }
                if ($donation->displayMode == 'button' || $donation->displayMode == 'modalButton') {
                    $classHidden = 'adns_hidden';
                    $response .= '<div id="adns_bootstraped" class="adns_bootstraped">';
                    $response .= '<p class="adns_startBtnContainer"><a href="javascript:" class="adns_startButton adns-btn adns-btn-primary attractive-donation-' . $donation->id . '"><span class="fa ' . $donation->introBtnIcon . '"></span>' . $donation->introBtnLabel . '</a></p>';
                    $response .= '</div>';
                } else if ($donation->displayMode == "") {
                    $classHidden = 'adns_open';
                }

                $subData = '';
                $subLabel = '';
                if ($donation->isSubscription) {
                    //$subData = 'data-subscription="true"';                    
                    $subLabel = 'data-sublabel="' . $donation->subscriptionLabel . '"';
                }


                $response .= '<div id="adns_bootstraped" class="adns_bootstraped">';
                $response .= '<div id="adns_overlay"></div>';
                $response .= '<div id="attractive-donation" ' . $subData . ' ' . $subLabel . ' class="' . $verticalClass . ' ' . $classHidden . ' ' . $classModal . '" data-donationid="' . $donation->id . '">';
                $response .= '<a href="javascript:" onclick="adns_closeModal(' . $donation->id . ');" class="adns_closeModalBtn"><span class="fa fa-remove"></span></a>';
                $response .= '<h1 class="adns_title">' . $donation->title . '</h1>';
                $response .= '<div class="adns_description">' . $donation->description . '</div>';
                $response .= '<div class="adns_donationContent">';
                $response .= '<div class="adns_progressbarContainer">';
                $response .= '<div class="adns_progressbar"></div>';
                $response .= '</div>';
                $response .= '<div class="adns_stepsContainer">';
                $tint = 'false';
                if ($donation->imageTint) {
                    $tint = 'true';
                }
                foreach ($steps as $step) {
                    $currentClass = '';
                    if ($step->startStep) {
                        $currentClass = 'adns_active';
                    }
                    $response .= '<div class="adns_step ' . $currentClass . '" data-stepid="' . $step->id . '" data-start="' . $step->startStep . '">';
                    $response .= '<div class="adns_imageContainer"><img data-tint="' . $tint . '" class="adns_imageCurrent" src="' . $step->image . '" alt="' . $step->content . '"/></div>';
                    // $response .= '<div class="adns_stepTitle">'.$step->content.'</div>';  
                    $response .= '</div>';
                }
                $response .= '</div>';
                $response .= '<div class="adns_stepSpacer"></div>';
                if ($donation->isSubscription) {
                    $response .= '<div id="adns_bootstraped" class="adns_bootstraped adns_panel"><div class="form-group"><label style="display: block;margin-top: 10px;">' . $donation->recurringLabel . '</label>'
                            . '<input type="checkbox" id="adns_recurringCB"  data-toggle="switch" data-on-label="<i class=\'fui-check\'></i>" data-off-label="<i class=\'fui-cross\'></i>" />'
                            . '</div></div>';
                }
                $response .= '<div class="adns_btnPaymentContainer">';
                if ($donation->use_stripe) {
                } else {

                    $returnUrl = $_SERVER["HTTP_HOST"] . $_SERVER["REQUEST_URI"];
                    if ($donation->paypal_useSandbox == 1) {
                        $response .= '<form id="adns_paypalForm" class="adns_paypalForm" action="https://www.sandbox.paypal.com/cgi-bin/webscr"  method="post">';
                    } else {
                        $response .= '<form id="adns_paypalForm" class="adns_paypalForm"  action="https://www.paypal.com/cgi-bin/webscr" method="post">';
                    }
                    $urlReturn = 'http://' . $_SERVER["HTTP_HOST"] . $_SERVER["REQUEST_URI"];

                    if (isset($_SERVER['HTTPS'])) {
                        $urlReturn = 'https://' . $_SERVER["HTTP_HOST"] . $_SERVER["REQUEST_URI"];
                    }

                    $response .= '
                            <a href="javascript:" onclick="adns_payPaypal(this);" class="adns-btn adns-btn-primary adns_btnPayment">' . $donation->btnPaymentTxt . '</a>
                            <input type="submit" style="display: none;" name="submit"/>
                            <img alt="" border="0" src="https://www.paypal.com/en_US/i/scr/pixel.gif" width="1" height="1">
                            <input type="hidden" name="add" value="1">
                            <input type="hidden" name="business" value="' . $donation->paypal_email . '">
                            <input type="hidden" name="business_cs_email" value="' . $donation->paypal_email . '">
                            <input type="hidden" name="item_name" value="' . $donation->title . '">
                            <input type="hidden" name="charset" value="utf-8">
                            <input type="hidden" name="no_shipping" value="1">
                            <input type="hidden" name="cn" value="Message">
                            <input type="hidden" name="currency_code" value="' . $donation->paypal_currency . '">
                            <input type="hidden" name="return" value="' . $urlReturn . '">
                                       ';
                    $response .= ' <input type="hidden" name="no_note" value="1">
                            <input type="hidden" name="src" value="1">
                            <input type="hidden" name="a3" value="15.00">
                            <input type="hidden" name="p3" value="' . $donation->paypal_subsFrequency . '">
                            <input type="hidden" name="t3" value="' . $donation->paypal_subsFrequencyType . '">
                            <input type="hidden" name="bn" value="PP-SubscriptionsBF:btn_subscribeCC_LG.gif:NonHostedGuest">';

                    $response .= '<input type="hidden" name="cmd" value="_donations">
                            <input type="hidden" name="amount" value="1">';
                    $response .= '
                        </form>';
                }
                $response .= '</div>';
                $response .= '</div>';
                $response .= '<div class="adns_finalMsg">' . $donation->finalMessage . '</div>';
                $response .= '</div>';
                $response .= '</div>';
            }
        }
        return $response;
    }

    
    private function getWebName($text) {
        $text = trim(ucwords($text));
        $text = preg_replace("/[^a-zA-Z0-9]+/", "", $text);
        return $text;
    }
    
    public function stripePreparePayment() {
        global $wpdb;
        $donationID = sanitize_text_field($_POST['donationID']);
        $amount = sanitize_text_field($_POST['amount']);
        $title = sanitize_text_field($_POST['title']);
        $isSub = ($_POST['isSub']);

        $table_name = $wpdb->prefix . "adns_donations";
        $donations = $wpdb->get_results($wpdb->prepare("SELECT * FROM $table_name WHERE id='%s' LIMIT 1", $donationID));
        if (count($donations) > 0) {
            $donation = $donations[0];
            require_once('stripe-php-6.38.0/init.php');
            if ($donation->stripe_secretKey != '') {
                \Stripe\Stripe::setApiKey($donation->stripe_secretKey);

                $amount *= 100;

                try {
                    if (!$isSub) {
                        try {
                            $session = \Stripe\Checkout\Session::create([
                                'payment_method_types' => ['card'],
                                'line_items' => [[
                                    'name' => $title,
                                    'description' => $donation->title,
                                    'amount' => $amount,
                                    'currency' => $donation->stripe_currency,
                                    'quantity' => 1,
                                ]],
                                'success_url' => get_home_url(),
                                'cancel_url' => get_home_url(),
                            ]);
                            echo $session->id;
                        } catch (\Stripe\Exception\ApiErrorException $e) {
                            echo 'Error: ' . $e->getMessage();
                        }
                    } else {
                        $planID = $this->getWebName($donation->title) . '-' . date('Y-m-d-H-i-s-u');
                        $plan = \Stripe\Plan::create([
                            "amount" => $amount,
                            "interval" => $donation->stripe_subsFrequencyType,
                            "interval_count" => 1,
                            "product" => [
                                "name" => $title
                            ],
                            "currency" => strtolower($donation->stripe_currency),
                            "id" => $planID,
                            "trial_period_days" => 0
                        ]);

                        $session = \Stripe\Checkout\Session::create([
                            'payment_method_types' => ['card'],
                            'subscription_data' => [
                                'items' => [[
                                    'plan' => $plan->id,
                                ]],
                            ],
                            'success_url' => get_home_url(),
                            'cancel_url' => get_home_url(),
                        ]);
                        echo $session->id;
                    }
                } catch (\Stripe\Exception\ApiErrorException $e) {
                    echo 'Error: ' . $e->getMessage();
                }
            } else {
                echo 'Error: Stripe secret key is missing.';
            }
        } else {
            echo 'Error: Donation not found.';
        }
        die();
    }

   
    public function conditionally_add_scripts_and_styles($posts) {
        if (empty($posts))
            return $posts;
        global $wpdb;
        if (!is_admin()) {

            if (!$this->checkedSc) {
                $shortcode_found = false;
                $donation_id = 0;
                $this->currentDonations[] = array();

                if (!isset($_GET['cornerstone_preview'])) {
                    foreach ($posts as $post) {
                        $lastPos = 0;
                        while (($lastPos = strpos($post->post_content, '[attractive-donation', $lastPos)) !== false) {
                            $shortcode_found = true;
                            $donation_id = false;
                            $this->checkedSc = true;
                            $lastPos = $lastPos + 20;
                            $pos_start = strpos($post->post_content, 'donation="', $lastPos) + 10;
                            $pos_end = strpos($post->post_content, '"', $pos_start);
                            if ($pos_start - $lastPos < 18) {
                                $donation_id = substr($post->post_content, $pos_start, $pos_end - $pos_start);
                            }
                            if ($donation_id && $donation_id > 0 && !is_array($donation_id)) {
                                $this->currentDonations[] = $donation_id;
                            } else {
                                $table_name = $wpdb->prefix . "adns_donations";
                                $donationReq = $wpdb->get_results("SELECT * FROM $table_name ORDER BY id ASC LIMIT 1");
                                if (count($donationReq) > 0) {
                                    $donation = $donationReq[0];
                                    $this->currentDonations[] = $donation->id;
                                }
                            }
                        }
                    }
                }
                if (isset($_GET['cornerstone_preview'])) {
                    wp_register_style($this->_token . '-frontend', esc_url($this->assets_url) . 'css/frontend.min.css', array(), $this->_version);
                    wp_enqueue_style($this->_token . '-frontend');
                } else if (!$shortcode_found && defined('CNR_DEV')) {
                    $table_name = $wpdb->prefix . "adns_donations";
                    $donationReq = $wpdb->get_results("SELECT * FROM $table_name ORDER BY id ASC");
                    if (count($donationReq) > 0) {
                        $shortcode_found = true;
                        $this->checkedSc = true;
                        foreach ($donationReq as $donation) {
                            $this->currentDonations[] = $donation->id;
                        }
                    }
                }

                //loadAllPages
                $table_name = $wpdb->prefix . "adns_donations";
                $donationReq = $wpdb->get_results("SELECT * FROM $table_name WHERE loadAllPages=1 ORDER BY id ASC");
                if (count($donationReq) > 0) {
                    $shortcode_found = true;
                    $this->checkedSc = true;
                    foreach ($donationReq as $donation) {
                        if (!in_array($donation->id, $this->currentDonations)) {
                            $this->currentDonations[] = $donation->id;
                        }
                    }
                }
                if (isset($_GET['adns_action']) && $_GET['adns_action'] == 'preview') {
                    $donationID = sanitize_text_field($_GET['donation']);
                    if (!in_array($donationID, $this->currentDonations)) {
                        $shortcode_found = true;
                        $this->checkedSc = true;
                        $this->currentDonations[] = $donationID;
                    }
                }

                if ($shortcode_found && count($this->currentDonations) > 0 && !isset($_GET['et_fb'])) {

                    // styles
                    wp_register_style($this->_token . '-reset', esc_url($this->assets_url) . 'css/reset.min.css', array(), $this->_version);
                    wp_enqueue_style($this->_token . '-reset');

                    wp_register_style($this->_token . '-bootstrap', esc_url($this->assets_url) . 'css/bootstrap.min.css', array(), $this->_version);
                    wp_enqueue_style($this->_token . '-bootstrap');
                    wp_register_style($this->_token . '-flat-ui', esc_url($this->assets_url) . 'css/flat-ui-pro.min.css', array(), $this->_version);
                    wp_enqueue_style($this->_token . '-flat-ui');
                    wp_register_style($this->_token . '-jqueryui', esc_url($this->assets_url) . 'css/jquery-ui-theme/jquery-ui.min.css', array(), $this->_version);
                    wp_enqueue_style($this->_token . '-jqueryui');
                    wp_register_style($this->_token . '-fontawesome', esc_url($this->assets_url) . 'css/font-awesome.min.css', array(), $this->_version);
                    wp_enqueue_style($this->_token . '-fontawesome');
                    wp_register_style($this->_token . '-frontend', esc_url($this->assets_url) . 'css/frontend.min.css', array(), $this->_version);
                    wp_enqueue_style($this->_token . '-frontend');

                    // scripts               
                    wp_register_script($this->_token . '-flatui', esc_url($this->assets_url) . 'js/flat-ui-pro.min.js', array('jquery',
                        'jquery-ui-core',
                        'jquery-ui-mouse',
                        'jquery-ui-position',
                        'jquery-ui-droppable',
                        'jquery-ui-draggable',
                        'jquery-ui-resizable',
                        'jquery-ui-sortable',
                        'jquery-effects-core',
                        'jquery-effects-drop',
                        'jquery-effects-fade',
                        'jquery-effects-bounce'), $this->_version);
                    wp_enqueue_script($this->_token . '-flatui');
                    wp_register_script($this->_token . '-touch-punch', esc_url($this->assets_url) . 'js/jquery.ui.touch-punch.min.js', array('jquery', 'jquery-ui-core', 'jquery-ui-position', 'jquery-ui-slider'), $this->_version);
                    wp_enqueue_script($this->_token . '-touch-punch');
                    wp_register_script($this->_token . '-frontend', esc_url($this->assets_url) . 'js/frontend.min.js', array($this->_token . '-touch-punch'), $this->_version);
                    wp_enqueue_script($this->_token . '-frontend');

                    $donationsArray = array();
                    foreach ($this->currentDonations as $donationID) {
                        if ($donationID > 0 && !is_array($donationID)) {
                            $table_name = $wpdb->prefix . "adns_donations";
                            $donationReq = $wpdb->get_results("SELECT * FROM $table_name WHERE id=$donationID LIMIT 1");
                            if (count($donationReq) > 0) {
                                $donationData = $donationReq[0];
                                $donation = new stdClass();
                                $donation->id = $donationData->id;
                                $donation->title = $donationData->title;
                                $donation->description = $donationData->description;
                                $donation->currency = $donationData->currency;
                                $donation->currencyPosition = $donationData->currencyPosition;
                                $donation->btnPaymentTxt = $donationData->btnPaymentTxt;
                                $donation->stripe_btnLabel = $donationData->stripe_btnLabel;
                                $donation->colorTint = $donationData->colorTint;
                                $donation->thousandsSeparator = $donationData->thousandsSeparator;
                                $donation->use_stripe = $donationData->use_stripe;
                                $donation->steps = array();
                                $table_name = $wpdb->prefix . "adns_steps";
                                $stepReq = $wpdb->get_results("SELECT * FROM $table_name WHERE donationID=$donationID ORDER BY amount ASC");
                                foreach ($stepReq as $step) {
                                    $donation->steps[] = $step;
                                }
                                $donationsArray[] = $donation;


                                if ($donationData->use_stripe) {
                                    wp_register_script('stripe-v3', 'https://js.stripe.com/v3/', array());
                                    wp_enqueue_script('stripe-v3');
                                    $donation->stripe_publishKey = $donationData->stripe_publishKey;
                                }
                            }
                        }
                    }
                    $js_data = array('ajaxurl' => admin_url('admin-ajax.php'), 'donations' => $donationsArray);
                    wp_localize_script($this->_token . '-frontend', 'adns_donations', $js_data);
                    add_action('wp_head', array($this, 'options_custom_styles'));
                }
            }
        }

        return $posts;
    }

    private function is_enqueued_script($script) {
        return isset($GLOBALS['wp_scripts']->registered[$script]);
    }

    public function options_custom_styles() {
        global $wpdb;

        $output = '';

        foreach ($this->currentDonations as $currentFaq) {
            if ($currentFaq > 0 && !is_array($currentFaq)) {
                $table_name = $wpdb->prefix . "adns_donations";
                $donationReq = $wpdb->get_results("SELECT * FROM $table_name WHERE id=" . $currentFaq . " ORDER BY id ASC");
                if (count($donationReq) > 0) {
                    $donation = $donationReq[0];
                    if ($donation) {
                        if ($donation->useGoogleFont && $donation->googleFontName != "") {
                            $fontname = str_replace(' ', '+', $donation->googleFontName);
                            $output .= '@import url(https://fonts.googleapis.com/css?family=' . $fontname . ':400,700);';

                            $output .= 'body #adns_bootstraped.adns_bootstraped #attractive-donation[data-donationid="' . $donation->id . '"] {';
                            $output .= ' font-family:"' . $donation->googleFontName . '"; ';
                            $output .= '}';
                        }
                        $output .= 'body #adns_bootstraped.adns_bootstraped #attractive-donation[data-donationid="' . $donation->id . '"] {';
                        $output .= ' background-color:' . $donation->colorBg . '; ';
                        $output .= '}';
                        $output .= 'body #adns_bootstraped.adns_bootstraped #attractive-donation[data-donationid="' . $donation->id . '"] .adns_title{';
                        $output .= ' color:' . $donation->colorTitle . '; ';
                        $output .= '}';
                        $output .= 'body #adns_bootstraped.adns_bootstraped #attractive-donation[data-donationid="' . $donation->id . '"] .adns-btn.adns-btn-primary {';
                        $output .= ' background-color:' . $donation->colorBtnBg . '; ';
                        $output .= ' color:' . $donation->colorBtnColor . '; ';
                        $output .= '}';
                        $output .= 'body #adns_bootstraped.adns_bootstraped #attractive-donation[data-donationid="' . $donation->id . '"] .adns-btn.adns-btn-primary:hover {';
                        $output .= ' background-color:' . $donation->colorBtnBgHover . '; ';
                        $output .= '}';
                        $output .= 'body #adns_bootstraped.adns_bootstraped #attractive-donation[data-donationid="' . $donation->id . '"] .adns_closeModalBtn {';
                        $output .= ' color:' . $donation->colorBtnBgHover . '; ';
                        $output .= '}';
                        $output .= 'body #adns_bootstraped.adns_bootstraped #attractive-donation[data-donationid="' . $donation->id . '"] .adns_progressbar {';
                        $output .= ' background-color:' . $donation->colorSliderBg . '; ';
                        $output .= '}';
                        $output .= 'body #adns_bootstraped.adns_bootstraped #attractive-donation[data-donationid="' . $donation->id . '"] .adns_progressbar .ui-slider-range,'
                                . 'body #adns_bootstraped.adns_bootstraped #attractive-donation[data-donationid="' . $donation->id . '"] .adns_progressbar .ui-slider-handle {';
                        $output .= ' background-color:' . $donation->colorBtnBg . '; ';
                        $output .= '}';
                        $output .= 'body #adns_bootstraped.adns_bootstraped #attractive-donation[data-donationid="' . $donation->id . '"] .adns_progressbar .ui-slider-handle:hover,'
                                . 'body #adns_bootstraped.adns_bootstraped #attractive-donation[data-donationid="' . $donation->id . '"] .adns_progressbar .ui-slider-handle.ui-state-active{';
                        $output .= ' background-color:' . $donation->colorBtnBgHover . '; ';
                        $output .= '}';

                        if ($donation->imagesMaxHeight > 0) {
                            $output .= 'body #adns_bootstraped.adns_bootstraped #attractive-donation[data-donationid="' . $donation->id . '"] .adns_imageContainer>.adns_imageCurrent {';
                            $output .= ' max-height:' . $donation->imagesMaxHeight . 'px; ';
                            $output .= '}';
                        } else {
                            $output .= 'body #adns_bootstraped.adns_bootstraped #attractive-donation[data-donationid="' . $donation->id . '"] .adns_imageContainer>.adns_imageCurrent {';
                            $output .= ' max-height: auto; ';
                            $output .= '}';
                        }

                        if ($donation->customCss != "") {
                            $output .= $donation->customCss;
                            $output .= "\n";
                        }
                    }
                }
            }
        }
        if ($output != '') {
            $output = "\n<style>\n" . $output . "</style>\n";
            echo $output;
        }
    }

    /**
     * Main ADS_Core Instance
     *
     *
     * @since 1.0.0
     * @static
     * @see ADS_Core()
     * @return Main ADS_Core instance
     */
    public static function instance($file = '', $version = '1.0.0') {
        if (is_null(self::$_instance)) {
            self::$_instance = new self($file, $version);
        }
        return self::$_instance;
    }

// End instance()

    /**
     * Cloning is forbidden.
     *
     * @since 1.0.0
     */
    public function __clone() {
        
    }

// End __clone()

    /**
     * Unserializing instances of this class is forbidden.
     *
     * @since 1.0.0
     */
    public function __wakeup() {
        //  _doing_it_wrong(__FUNCTION__, __('Cheatin&#8217; huh?'), $this->_version);
    }

// End __wakeup()

    /**
     * Return settings.
     * @access  public
     * @since   1.0.0
     * @return  void
     */
    public function getSettings() {
        global $wpdb;
        $table_name = $wpdb->prefix . "adns_settings";
        $settings = $wpdb->get_results("SELECT * FROM $table_name WHERE id=1 LIMIT 1");
        return $settings[0];
    }

    // End getSettings()

    /**
     * Log the plugin version number.
     * @access  public
     * @since   1.0.0
     * @return  void
     */
    private function _log_version_number() {
        update_option($this->_token . '_version', $this->_version);
    }

}
